@@ -17,7 +17,7 @@ import           Hakyll.Core.Metadata
 import           Hakyll.Core.Routes
 import           Hakyll.Core.Rules
 import           Hakyll.Core.Rules.Internal
-import           System.FilePath                ((</>))
+import           System.FilePath                ((</>), normalise)
 import           Test.Tasty                     (TestTree, testGroup)
 import           Test.Tasty.HUnit               (Assertion, (@=?))
 import           TestSuite.Util
@@ -39,7 +39,7 @@ case01 = do
     let identifiers     = S.fromList $ map fst $ rulesCompilers ruleSet
         routes          = rulesRoutes ruleSet
         checkRoute ex i =
-            runRoutes routes provider i >>= \(r, _) -> Just ex @=? r
+            runRoutes routes provider i >>= \(r, _) -> Just (normalise ex) @=? r
 
     -- Test that we have some identifiers and that the routes work out
     S.fromList expected @=? identifiers
